@@ -401,12 +401,12 @@ class MsiTokenProvider(CloudInfoTokenProvider):
     def close(self):
         if self._msi_auth_context is not None:
             self._msi_auth_context.close()
-        if self._msi_auth_context is not None:
+        if self._msi_auth_context_async is not None:
             raise KustoAsyncUsageError("Can't close async token provider with sync close", self.is_async)
 
     async def close_async(self):
         if self._msi_auth_context is not None:
-            sync_to_async(self._msi_auth_context.close())
+            await sync_to_async(self._msi_auth_context.close())
 
         if self._msi_auth_context_async is not None:
             await self._msi_auth_context_async.close()
@@ -472,7 +472,7 @@ class AzCliTokenProvider(CloudInfoTokenProvider):
 
     async def close_async(self):
         if self._az_auth_context is not None:
-            sync_to_async(self._az_auth_context.close())
+            await sync_to_async(self._az_auth_context.close())
 
         if self._az_auth_context_async is not None:
             await self._az_auth_context_async.close()
@@ -697,7 +697,7 @@ class AzureIdentityTokenCredentialProvider(CloudInfoTokenProvider):
             if inspect.iscoroutinefunction(self.credential.close):
                 await self.credential.close()
             else:
-                sync_to_async(self.credential.close)()
+                await sync_to_async(self.credential.close)()
             self.credential = None
             self.credential_from_login_endpoint = None
 
