@@ -24,6 +24,7 @@ setup(
     name=PACKAGE_NAME,
     version=VERSION,
     description="Kusto Data Client",
+    long_description_content_type="text/markdown",
     long_description=open("README.rst", "r").read(),
     url="https://github.com/Azure/azure-kusto-python",
     author="Microsoft Corporation",
@@ -34,19 +35,20 @@ setup(
         "Development Status :: 4 - Beta",
         "Intended Audience :: Developers",
         "Topic :: Software Development",
-        "Programming Language :: Python :: 3.7",
+        "Programming Language :: Python :: 3.8",
         "Programming Language :: Python :: 3.8",
         "Programming Language :: Python :: 3.9",
         "Programming Language :: Python :: 3.10",
         "Programming Language :: Python :: 3.11",
         "Programming Language :: Python :: 3.12",
+        "Programming Language :: Python :: 3.13",
         "License :: OSI Approved :: MIT License",
     ],
     namespace_packages=["azure"],
     keywords="kusto wrapper client library",
     packages=find_packages(exclude=["azure", "*tests*", "*tests.*"]),
-    package_data={"": ["wellKnownKustoEndpoints.json", "py.typed"]},
+    package_data={"": ["wellKnownKustoEndpoints.json", "py.typed", "kcsb.json"]},
     include_package_data=True,
-    install_requires=["python-dateutil>=2.8.0", "requests>=2.13.0", "azure-identity>=1.5.0,<2", "msal>=1.9.0,<2", "ijson~=3.1", "azure-core>=1.11.0,<2"],
+    install_requires=["python-dateutil>=2.8.0", "requests>=2.32.3", "azure-identity>=1.21.0,<2", "msal>=1.9.0,<2", "ijson~=3.1", "azure-core>=1.11.0,<2"],
     extras_require={"pandas": ["pandas"], "aio": ["aiohttp>=3.8.0,<4", "asgiref>=3.2.3,<4"]},
 )
