@@ -352,10 +352,12 @@ class TokenProviderTests(unittest.TestCase):
 
     @staticmethod
     def test_azure_identity_default_token_provider():
-        app_id, app_key, auth_id = prepare_app_key_auth(optional=True)
-        if not app_id or not app_key or not auth_id:
+        auth = prepare_app_key_auth(optional=True)
+        if not auth:
             pytest.skip(" *** Skipped Azure Identity Provider Test ***")
 
+        app_id, app_key, auth_id = auth
+
         with AzureIdentityTokenCredentialProvider(KUSTO_URI, credential=DefaultAzureCredential()) as provider:
             token = provider.get_token()
             assert TokenProviderTests.get_token_value(token) is not None
@@ -368,3 +370,21 @@ class TokenProviderTests(unittest.TestCase):
         ) as provider:
             token = provider.get_token()
             assert TokenProviderTests.get_token_value(token) is not None
+
+    @staticmethod
+    def test_sanity_close():
+        DUMMY_URI = "https://dummy_uri.kusto.windows.net"
+        providers = [
+            MsiTokenProvider(DUMMY_URI),
+            AzCliTokenProvider(DUMMY_URI),
+            UserPassTokenProvider(DUMMY_URI, "organizations", "a", "b"),
+            ApplicationKeyTokenProvider(DUMMY_URI, "a", "b", "c"),
+            ApplicationCertificateTokenProvider(DUMMY_URI, "a", "b", "c", "d"),
+            CallbackTokenProvider(lambda: "a", None),
+            AzureIdentityTokenCredentialProvider(DUMMY_URI, credential=DefaultAzureCredential()),
+            DeviceLoginTokenProvider(DUMMY_URI, "organizations", lambda x, x2, x3: None),
+        ]
+
+        for provider in providers:
+            with provider:
+                pass
