@@ -10,7 +10,7 @@ from azure.kusto.data import KustoClient, KustoConnectionStringBuilder, ClientRe
 
 from ._ingest_telemetry import IngestTracingAttributes
 from .base_ingest_client import BaseIngestClient, IngestionResult, IngestionStatus
-from .descriptors import FileDescriptor, StreamDescriptor
+from .descriptors import FileDescriptor, StreamDescriptor, BlobDescriptor
 from .ingestion_properties import IngestionProperties
 
 
@@ -21,11 +21,17 @@ class KustoStreamingIngestClient(BaseIngestClient):
     Tests are run using pytest.
     """
 
-    def __init__(self, kcsb: Union[KustoConnectionStringBuilder, str]):
+    def __init__(self, kcsb: Union[KustoConnectionStringBuilder, str], auto_correct_endpoint: bool = True):
         """Kusto Streaming Ingest Client constructor.
         :param KustoConnectionStringBuilder kcsb: The connection string to initialize KustoClient.
         """
         super().__init__()
+
+        if isinstance(kcsb, str):
+            kcsb = KustoConnectionStringBuilder(kcsb)
+
+        if auto_correct_endpoint:
+            kcsb["Data Source"] = BaseIngestClient.get_query_endpoint(kcsb.data_source)
         self._kusto_client = KustoClient(kcsb)
 
     def close(self):
@@ -79,9 +85,30 @@ class KustoStreamingIngestClient(BaseIngestClient):
             ingestion_properties.database,
             ingestion_properties.table,
             stream_descriptor.stream,
+            None,
             ingestion_properties.format.name,
             additional_properties,
             mapping_name=ingestion_properties.ingestion_mapping_reference,
         )
 
         return IngestionResult(IngestionStatus.SUCCESS, ingestion_properties.database, ingestion_properties.table, stream_descriptor.source_id)
+
+    def ingest_from_blob(
+        self, blob_descriptor: BlobDescriptor, ingestion_properties: IngestionProperties, client_request_id: Optional[str] = None
+    ) -> IngestionResult:
+        IngestTracingAttributes.set_ingest_descriptor_attributes(blob_descriptor, ingestion_properties)
+        additional_properties = None
+        if client_request_id:
+            additional_properties = ClientRequestProperties()
+            additional_properties.client_request_id = client_request_id
+
+        self._kusto_client.execute_streaming_ingest(
+            ingestion_properties.database,
+            ingestion_properties.table,
+            None,
+            blob_descriptor.path,
+            ingestion_properties.format.name,
+            additional_properties,
+            mapping_name=ingestion_properties.ingestion_mapping_reference,
+        )
+        return IngestionResult(IngestionStatus.SUCCESS, ingestion_properties.database, ingestion_properties.table, blob_descriptor.source_id)
